@@ -6,7 +6,7 @@
 #![forbid(unsafe_code)]
 
 #[macro_use]
-extern crate mybatis_macro;
+pub extern crate mybatis_macro;
 #[macro_use]
 pub extern crate mybatis_sql;
 
